@@ -1,3 +1,3 @@
-from bug import Bug, BugException
+from bug import Bug, BugException, Comment
 from bugsy import Bugsy, BugsyException, LoginException
 from search import Search
\ No newline at end of file
