@@ -5,6 +5,8 @@ from bug import Bug
 from search import Search
 
 
+
+
 class BugsyException(Exception):
     """
         If while interacting with Bugzilla and we try do something that is not
@@ -32,6 +34,9 @@ class Bugsy(object):
         Bugsy allows easy getting and putting of Bugzilla bugs
     """
 
+    DEFAULT_SEARCH = ['version', 'id', 'summary', 'status', 'op_sys',
+                      'resolution', 'product', 'component', 'platform']
+
     def __init__(self, username=None, password=None, bugzilla_url='https://bugzilla.mozilla.org/rest'):
         """
             Initialises a new instance of Bugsy
@@ -46,11 +51,16 @@ class Bugsy(object):
         """
         self.username = username
         self.password = password
-        self.token = None
         self.bugzilla_url = bugzilla_url
+        self.token = None
+        self.session = requests.Session()
+
         if self.username and self.password:
-            result = requests.get(bugzilla_url + '/login?login=%s&password=%s' % (self.username, self.password)).json()
+            result = self.request('login',
+                params={'login': username, 'password': password})
+            result = result.json()
             if result.has_key('token'):
+                self.session.params['token'] = result['token']
                 self.token = result['token']
             else:
                 raise LoginException(result['message'])
@@ -65,12 +75,8 @@ class Bugsy(object):
             >>> bugzilla = Bugsy()
             >>> bug = bugzilla.get(123456)
         """
-        url = self.bugzilla_url + "/bug/%s" % bug_number
-        if self.token:
-            url = url + "?token=%s" % self.token
-
-        bug = requests.get(url).json()
-        return Bug(self.bugzilla_url, self.token, **bug['bugs'][0])
+        bug = self.request('bug/%s' % bug_number, params={"include_fields" : self. DEFAULT_SEARCH}).json()
+        return Bug(self, **bug['bugs'][0])
 
     def put(self, bug):
         """
@@ -95,18 +101,29 @@ class Bugsy(object):
             raise BugsyException("Please pass in a Bug object when posting to Bugzilla")
 
         if not bug.id:
-            result = requests.post(self.bugzilla_url + "/bug?token=%s" % self.token, bug.to_dict()).json()
+            result = self.request('bug', 'POST', data=bug.to_dict()).json()
             if not result.has_key('error'):
                 bug._bug['id'] = result['id']
+                bug._bugsy = self
             else:
                 raise BugsyException(result['message'])
         else:
-            requests.post(self.bugzilla_url + "/bug/%s?token=%s" % (bug.id, self.token), bug.to_dict())
+            self.session.post('%s/bug/%s' % (self.bugzilla_url, bug.id),
+                data=bug.to_dict())
 
-    def search_for():
-        doc = "The search_for property."
-        def fget(self):
-            return Search(self.bugzilla_url, self.token)
-        return locals()
-    search_for = property(**search_for())
+    @property
+    def search_for(self):
+        return Search(self)
+
+    def request(self, path, method='GET', **kwargs):
+        """Perform a HTTP request.
+
+        Given a relative Bugzilla URL path, an optional request method,
+        and arguments suitable for requests.Request(), perform a
+        HTTP request.
+        """
+        headers = {"User-Agent": "Bugsy"}
+        kwargs['headers'] = headers
+        url = '%s/%s' % (self.bugzilla_url, path)
+        return self.session.request(method, url, **kwargs)
 
